==> qr-clj-0.4.2.jar: qr_clj/core.clj <==
;;   Copyright (c) 7theta. All rights reserved.
;;   The use and distribution terms for this software are covered by the
;;   MIT License (https://opensource.org/licenses/MIT) which can also be
;;   found in the LICENSE file at the root of this distribution.
;;
;;   By using this software in any fashion, you are agreeing to be bound by
;;   the terms of this license.
;;   You must not remove this notice, or any others, from this software.

(ns qr-clj.core
  (:require [utilis.fs :refer [ensure-temp-dir]]
            [clojure.java.io :as io])
  (:import [com.google.zxing BarcodeFormat BinaryBitmap ResultMetadataType]
           [com.google.zxing.qrcode QRCodeWriter QRCodeReader]
           [com.google.zxing.client.j2se
            MatrixToImageWriter BufferedImageLuminanceSource]
           [com.google.zxing.common HybridBinarizer]
           [javax.imageio ImageIO]))

(defn encode ^bytes
  [^bytes b w h]
  (ensure-temp-dir
   (let [os (java.io.ByteArrayOutputStream.)]
     (-> (QRCodeWriter.)
         (.encode (apply str (map #(char (bit-and % 255)) b))
                  BarcodeFormat/QR_CODE w h)
         (MatrixToImageWriter/writeToStream "png" os))
     (.toByteArray os))))

(defn decode ^bytes
  [^bytes b]
  (let [bitmap (-> (io/input-stream b)
                   ImageIO/read
                   BufferedImageLuminanceSource.
                   HybridBinarizer.
                   BinaryBitmap.)]
    (-> (QRCodeReader.)
        (.decode bitmap)
        .getResultMetadata
        (get ResultMetadataType/BYTE_SEGMENTS)
        first)))

==> qr-clj-0.4.3.jar: qr_clj/core.clj <==
;;   Copyright (c) 7theta. All rights reserved.
;;   The use and distribution terms for this software are covered by the
;;   MIT License (https://opensource.org/licenses/MIT) which can also be
;;   found in the LICENSE file at the root of this distribution.
;;
;;   By using this software in any fashion, you are agreeing to be bound by
;;   the terms of this license.
;;   You must not remove this notice, or any others, from this software.

(ns qr-clj.core
  (:require [utilis.fs :refer [ensure-temp-dir]]
            [clojure.java.io :as io])
  (:import [com.google.zxing BarcodeFormat BinaryBitmap ResultMetadataType]
           [com.google.zxing.qrcode QRCodeWriter QRCodeReader]
           [com.google.zxing.client.j2se
            MatrixToImageWriter BufferedImageLuminanceSource]
           [com.google.zxing.common HybridBinarizer]
           [javax.imageio ImageIO]
           [java.io InputStream]))

(defn encode ^bytes
  [^bytes b w h]
  (ensure-temp-dir
   (let [os (java.io.ByteArrayOutputStream.)]
     (-> (QRCodeWriter.)
         (.encode (apply str (map #(char (bit-and % 255)) b))
                  BarcodeFormat/QR_CODE w h)
         (MatrixToImageWriter/writeToStream "png" os))
     (.toByteArray os))))

(defn decode ^bytes
  [b]
  (let [^InputStream is (if (instance? InputStream b) b (io/input-stream b))
        bitmap (-> is
                   ImageIO/read
                   BufferedImageLuminanceSource.
                   HybridBinarizer.
                   BinaryBitmap.)]
    (-> (QRCodeReader.)
        (.decode bitmap)
        .getResultMetadata
        (get ResultMetadataType/BYTE_SEGMENTS)
        first)))
